import * as cdk from "aws-cdk-lib";
import * as constructs from "constructs";
/**
 * Retrieves or creates projects in any given Atlas organization.
 *
 * @schema CfnProjectProps
 */
export interface CfnProjectProps {
    /**
     * Name of the project to create.
     *
     * @schema CfnProjectProps#Name
     */
    readonly name: string;
    /**
     * Unique identifier of the organization within which to create the project.
     *
     * @schema CfnProjectProps#OrgId
     */
    readonly orgId: string;
    /**
     * Flag that indicates whether to create the project with default alert settings.
     *
     * @schema CfnProjectProps#WithDefaultAlertsSettings
     */
    readonly withDefaultAlertsSettings?: boolean;
    /**
     * @schema CfnProjectProps#ProjectSettings
     */
    readonly projectSettings?: ProjectSettings;
    /**
     * Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used
     *
     * @schema CfnProjectProps#Profile
     */
    readonly profile?: string;
    /**
     * @schema CfnProjectProps#ProjectTeams
     */
    readonly projectTeams?: ProjectTeam[];
    /**
     * @schema CfnProjectProps#ProjectApiKeys
     */
    readonly projectApiKeys?: ProjectApiKey[];
}
/**
 * Converts an object of type 'CfnProjectProps' to JSON representation.
 */
export declare function toJson_CfnProjectProps(obj: CfnProjectProps | undefined): Record<string, any> | undefined;
/**
 * @schema projectSettings
 */
export interface ProjectSettings {
    /**
     * @schema projectSettings#IsCollectDatabaseSpecificsStatisticsEnabled
     */
    readonly isCollectDatabaseSpecificsStatisticsEnabled?: boolean;
    /**
     * @schema projectSettings#IsDataExplorerEnabled
     */
    readonly isDataExplorerEnabled?: boolean;
    /**
     * @schema projectSettings#IsPerformanceAdvisorEnabled
     */
    readonly isPerformanceAdvisorEnabled?: boolean;
    /**
     * @schema projectSettings#IsRealtimePerformancePanelEnabled
     */
    readonly isRealtimePerformancePanelEnabled?: boolean;
    /**
     * @schema projectSettings#IsSchemaAdvisorEnabled
     */
    readonly isSchemaAdvisorEnabled?: boolean;
}
/**
 * Converts an object of type 'ProjectSettings' to JSON representation.
 */
export declare function toJson_ProjectSettings(obj: ProjectSettings | undefined): Record<string, any> | undefined;
/**
 * @schema projectTeam
 */
export interface ProjectTeam {
    /**
     * @schema projectTeam#TeamId
     */
    readonly teamId?: string;
    /**
     * @schema projectTeam#RoleNames
     */
    readonly roleNames?: string[];
}
/**
 * Converts an object of type 'ProjectTeam' to JSON representation.
 */
export declare function toJson_ProjectTeam(obj: ProjectTeam | undefined): Record<string, any> | undefined;
/**
 * @schema projectApiKey
 */
export interface ProjectApiKey {
    /**
     * @schema projectApiKey#Key
     */
    readonly key?: string;
    /**
     * @schema projectApiKey#RoleNames
     */
    readonly roleNames?: string[];
}
/**
 * Converts an object of type 'ProjectApiKey' to JSON representation.
 */
export declare function toJson_ProjectApiKey(obj: ProjectApiKey | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `MongoDB::Atlas::Project`
 *
 * @cloudformationResource MongoDB::Atlas::Project
 * @stability external
 */
export declare class CfnProject extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "MongoDB::Atlas::Project";
    /**
     * Resource props.
     */
    readonly props: CfnProjectProps;
    /**
     * Attribute `MongoDB::Atlas::Project.Id`
     */
    readonly attrId: string;
    /**
     * Attribute `MongoDB::Atlas::Project.Created`
     */
    readonly attrCreated: string;
    /**
     * Attribute `MongoDB::Atlas::Project.ProjectOwnerId`
     */
    readonly attrProjectOwnerId: string;
    /**
     * Attribute `MongoDB::Atlas::Project.ClusterCount`
     */
    readonly attrClusterCount: number;
    /**
     * Create a new `MongoDB::Atlas::Project`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnProjectProps);
}
